checkRequire("Lua_ChampionshipPanel");
checkRequire("Lua_ChampionshipMySchedulePanel");
checkRequire("Lua_ChampionshipQuizPanel");
checkRequire("Lua_ChampionshipSchedulePanel");
Lua_ChampionshipWindow = class("Lua_ChampionshipWindow", Lua_Window)
function Lua_ChampionshipWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_ChampionshipWindow";
	self.isFullSizeWin = true;
	self.isSingleShowWin = true;
	self.showWinBg = true;
	self.winBgPath = "/images/championship/xui_jys_bg_1.jpg";
	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_ChampionshipWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("CHAMPIONSHIP_INFO", self, self.showModel);
	self:addLuaEvent("UPDATE_DRESSUP_INFO", self, self.showModel);

	self.roleInfoPanel = Lua_RoleInfoPanel.new(self.content);
	self.roleInfoPanel:setRectAnchor(1);

	self.btnBg = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_widget_002", 0, 60.5, 720, 121);
	self.btnBg.anchorValue = 7;

	self.btnInfo = Array();
	self.btnInfo:add({ textAtlas = "championship_1", textNormalSprite = "xui_jys_zgnbutton_1_n", textSelectedSprite = "xui_jys_zgnbutton_1_p", 
		panel = Lua_ChampionshipPanel, redPointId = Lua_RedPointList.Championship_Main });
	self.btnInfo:add({ textAtlas = "championship_1", textNormalSprite = "xui_jys_zgnbutton_2_n", textSelectedSprite = "xui_jys_zgnbutton_2_p",
		panel = Lua_ChampionshipMySchedulePanel, redPointId = Lua_RedPointList.Championship_MySchedule });
	self.btnInfo:add({ textAtlas = "championship_1", textNormalSprite = "xui_jys_zgnbutton_3_n", textSelectedSprite = "xui_jys_zgnbutton_3_p",
		panel = Lua_ChampionshipQuizPanel, redPointId = Lua_RedPointList.Championship_Quiz });
	self.btnInfo:add({ textAtlas = "championship_1", textNormalSprite = "xui_jys_zgnbutton_4_n", textSelectedSprite = "xui_jys_zgnbutton_4_p",
		panel = Lua_ChampionshipSchedulePanel });

    self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
    self.btnList:setRectAnchor(7);
    self.btnList:setRectPivot(5);
    self.btnList.pivot = -1;
    self.btnList:setLocation(360, 53.5, 0);
    self.btnList:setButtonStyle("common_altas_1", "ui_common_button_001_b", "ui_common_button_001_b", 118, 108, 0.01, 1);
    self.btnList:setButtonLine("common_altas_1", "ui_common_line_011", 2, 108, 0, 0, 1);
    self.btnList:setButtonItem(120, 108);
    self.btnList:setRedPoint(40, 40);
    self.btnList:setClickCallBack(self, self.onButtonClick);
    self.btnList:setData(self.btnInfo);

	self.quizRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Championship_QuizTips)
	self.quizRedPoint:setRectAnchor(7)
	self.quizRedPoint:setLocation(220, 90)

    self:createBackBtn();
end

function Lua_ChampionshipWindow:onBackBtnClick()
	DataCenter.funcPathUtil:gotoFunction(1038, true);
end

function Lua_ChampionshipWindow:dispose()
	LuaUtil.setSceneDataExtendVal("FurEffShow", false);
	if self.roleInfoPanel then
		self.roleInfoPanel:dispose();
		self.roleInfoPanel = nil;
	end
	if self.showPanel then
		self.showPanel:dispose();
		self.showPanel = nil;
	end
	if self.btnList then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.btnInfo then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	if self.quizRedPoint then
		self.quizRedPoint:dispose();
		self.quizRedPoint = nil;
	end
	self:disposeModel();
	self:superCall("dispose");
end

function Lua_ChampionshipWindow:showWin(param)
	self:superCall("showWin", param);

	local index;
	if type(param) == "table" then
		index = param.main_id;
	elseif type(param) == "number" then
		index = param;
	end
	self.btnList:setSelected(index or 1);
	
	self:showScene();
end

function Lua_ChampionshipWindow:resetActive(bActive)
	self:superCall("resetActive", bActive);
	if bActive then
		self:showModel();
	else
		self:disposeModel();
	end
end

function Lua_ChampionshipWindow:onButtonClick(index, data)
	self.winBg:setEnable(index > 1)
	if index == 3 then
		self:showModel();
	elseif index == 3 then
		self.quizRedPoint:clickHandler();
	end

	if self.showPanel ~= nil then
		self.showPanel:dispose();
		self.showPanel = nil;
	end
	self.showPanel = data.panel.new(self.content);
	self.showPanel:setRectAnchor(9);
end

function Lua_ChampionshipWindow:showScene()
	if self.modelScenePanel == nil then
		self.modelScenePanel = Lua_MultiModelScenePanel.new();
	end
	self.modelScenePanel:showModelScene(Lua_SceneDefine.CHAMPION_SHIP);
end

function Lua_ChampionshipWindow:showModel()
	if Lua_WindowUtil.isWindowShowing("Lua_HeroLineupWindow") then
		return;
	end

	self:showScene();
	local list = DataCenter.championshipData.topPlayerList;
	local modelDic = {{0, 0, 0}, {1.7, 0, -0.5}, {-1.7, 0, -0.5}};
	for i = 1, 3 do
		if list and #list >= i then
			if DataCenter.roleData:isMyself(list[i].show_role.id) then
				data = DataCenter.roleData:getOwnDressUpId(Lua_DressUpDefine.MAINTYPE_MODEL);
			else
				data = DataCenter.roleData:getDressUpId(Lua_DressUpDefine.MAINTYPE_MODEL, list[i].show_role.dress_info)
			end
			data = DataCenter.roleUtil:getDressUpVoById(data)
			if data then
				if data.bShowFur then
					LuaUtil.setSceneDataExtendVal("FurEffShow", true);
				end
				self.modelScenePanel:addSingleModel(i, data.uiModelUrl, data.uiModelAvatarName, nil, data.uiModelDir, 1, modelDic[i], true);
			end
		end
	end
end

function Lua_ChampionshipWindow:disposeModel()
	if self.modelScenePanel then
		self.modelScenePanel:dispose()
		self.modelScenePanel = nil
	end
end