-- 大厅
Lua_ChampionshipPanel = class("Lua_ChampionshipPanel", Lua_DisplayObject)
function Lua_ChampionshipPanel:ctor(p)
	self:superCall("ctor", p, "ChampionshipPanel_skin");
end

function Lua_ChampionshipPanel:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("CHAMPIONSHIP_INFO", self, self.updateShowInfo);
	self:addLuaEvent("CHAMPIONSHIP_LIKE_UPDATE", self, self.updateLikeInfo);

	self.checkStore:addClickFuntion(self, self.onCheckStore);
	self.checkRank:addClickFuntion(self, self.onCheckRank);
	self.checkReward:addClickFuntion(self, self.onCheckReward);
	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.btnLayOut:addClickFuntion(self, self.onBtnLayOutClick);

	self.bgEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_jys_bg_01_2", "ui_jys_bg_01_2", 0, 0)

	self.likeRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Championship_Like);
	self.likeRedPoint:setRectAnchor(1);
	self.likeRedPoint:setLocation(335, -95);

	self:onRequestInfo();
	self:startTimer();
end

function Lua_ChampionshipPanel:dispose()
	self:stopTimer();
	DataCenter.preLoadData:removeBySign("Lua_HeroLineupWindow", self, self.onSceneShow);
	if self.bgEff then
		self.bgEff:dispose();
		self.bgEff = nil;
	end
	if self.fireEff then
		self.fireEff:dispose();
		self.fireEff = nil;
	end
	if self.likeRedPoint then
		self.likeRedPoint:dispose();
		self.likeRedPoint = nil;
	end
	if self.modelArr then
		self.modelArr:dispose();
		self.modelArr:clear();
		self.modelArr = nil;
	end
	self:superCall("dispose");
end

function Lua_ChampionshipPanel:onRequestInfo()
	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sWinInfo();
end

function Lua_ChampionshipPanel:updateShowInfo()
	local data = DataCenter.championshipData;
	if data.historyRank <= 0 then
		self.myRankText:setLangValue(540001);
	else
		self.myRankText.text = LanUtil.formateStr(540002, tostring(data.historyRank));
	end

	self.endTime = nil;
	if data.stageInfo ~= nil and DataCenter.roleData:checkInTime(data.startTick, data.endTick) then
		self.seasonText.text = LanUtil.formateStr(540004, DataCenter.championshipUtil:getScheduleStr(data.stageInfo.event_type, data.stageInfo.round));
		if data.curRank > 0 then
			self.curRankText.text = LanUtil.formateStr(540013, tostring(data.curRank));
		else
			self.curRankText:setLangValue(540076);
		end

		local serverTime = DataCenter.roleData.serverTime;
		if serverTime < tonumber(data.stageInfo.prepare_end_tick) then -- 准备阶段
			self.endTime = tonumber(data.stageInfo.prepare_end_tick);
		elseif serverTime < tonumber(data.stageInfo.guress_end_tick) then -- 竞猜阶段
			self.endTime = tonumber(data.stageInfo.guress_end_tick);
		elseif serverTime < tonumber(data.stageInfo.fight_end_tick) then -- 战斗阶段
			self.endTime = tonumber(data.stageInfo.fight_end_tick);
		end
	else
		self.seasonText:setLangValue(540003);
		self.curRankText:setLangValue(540012);
	end
	self.timeText.text = LanUtil.formateStr(540014, Lua_TimeTransform.transSeconds25(data.startTick, false), os.date("%H", data.startTick));
	self.condText.text = LanUtil.formateStr(540015, tostring(data.arenaRank));

	self:updateRankInfo(data.topPlayerList);
	self:startTimer();
end

function Lua_ChampionshipPanel:updateLikeInfo(msg)
	if msg == nil or self.modelArr == nil then
		return;
	end

	local item;
	for i = 1, self.modelArr:getSize() do
		item = self.modelArr[i];
		if item.data ~= nil and item.data.id == msg.role_info.id then
			item.data = msg.role_info;
		end
		item:updateData();
	end
end

function Lua_ChampionshipPanel:updateRankInfo(list)
	if self.modelArr == nil then
		self.modelArr = Array();
	end
	local posDic = {{3, -15}, {-235, -2}, {232, -2}};
	local item;
	for i = 1, 3 do
		item = self.modelArr[i];
		if item == nil then
			item = Lua_ChampionshipModelItem.new(self.content);
			item:setSiblingIndex(i - 1);
			self.modelArr:add(item);
		end
		if list == nil or #list < i then
			item:setData(i, nil);
		else
			item:setData(i, list[i]);
		end
		item:setLocation(posDic[i][1], posDic[i][2], 0);
	end
end

function Lua_ChampionshipPanel:startTimer()
	if self.bTimer ~= true then
		self.bTimer = true;
		self.startTime = getTime();
		self:addTimer("Lua_ChampionshipPanel", 0.01, self, self.onTimer, nil, -1);
	end
end

function Lua_ChampionshipPanel:stopTimer()
	if self.bTimer == true then
		self.bTimer = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_ChampionshipPanel:onTimer()
	if self.waitTime == nil or getTime() - self.startTime >= self.waitTime then
		local param = DataCenter.championshipUtil.fireRandomParam
		if param and #param > 0 then
			local len = #param
			local index = len
			if len > 1 then
				index = getRandomRange(len)
				while self.curFireIdx == index do
					index = getRandomRange(len)
				end
				self.curFireIdx = index
			end
			param = param[index]

			if self.fireEff == nil then
				self.fireEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_jys_bg_01_1", "ui_jys_bg_01_1", 0, 0)
			else
				self.fireEff:setEnable(false)
				self.fireEff:setEnable(true)
			end
			self.fireEff:setLocation(param[1], param[2], 0)
			self.fireEff:setScale(param[3], param[3], param[3])
		end
		self.waitTime = 5
		self.startTime = getTime()
	end

	if self.endTime and self.endTime > 0 then
		if self.endTime - DataCenter.roleData.serverTime <= 0 then
			self.endTime = nil;
			self:onRequestInfo();
		end
	end
end

function Lua_ChampionshipPanel:onCheckStore(go)
	DataCenter.funcPathUtil:gotoFunction(1095)
end

function Lua_ChampionshipPanel:onCheckRank(go)
	self.likeRedPoint:clickHandler();
	DataCenter.funcPathUtil:gotoFunction(1096)
end

function Lua_ChampionshipPanel:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_ChampionshipRewardWindow", Lua_WinParam.ACTION_OPEN, 1);
end

function Lua_ChampionshipPanel:onCheckHelp(go)
	local tipsData = { des = LanUtil.getValue(540000), isBottomShow = true, posX = 170, posY = 225 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ChampionshipPanel:onBtnLayOutClick(go)
	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_CHAMPIONSHIP);
	DataCenter.preLoadData:preShowScene("Lua_HeroLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, nil, sceneId, 0);
end

function Lua_ChampionshipPanel:onSceneShow(param)
	Lua_WindowUtil.openWin("Lua_HeroLineupWindow", Lua_WinParam.ACTION_OPEN, Lua_HeroUtil.LINEUP_CHAMPIONSHIP);
end




















Lua_ChampionshipModelItem = class("Lua_ChampionshipModelItem", Lua_DisplayObject)
function Lua_ChampionshipModelItem:ctor(p)
	self:superCall("ctor", p, "ChampionshipModelItem_skin");
end

function Lua_ChampionshipModelItem:buildShowItem()
	self:superCall("buildShowItem");
	self.btnLike:addClickFuntion(self, self.onLikeClick);
	self.clickArea:addClickFuntion(self, self.onClick);
end

function Lua_ChampionshipModelItem:dispose()
	if self.redPoint then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChampionshipModelItem:setData(rank, data)
	self.data = data;

	if rank == 1 then
		self.titleIcon:setAltas("role_title_1", "304000001");
		self.titleIcon:setLocation(0, 430, 0);
		self.rankIcon:setAltas("championship_1", "xui_jys_label_17");
		self.clickArea:SetDimensions(200, 360);
		self.clickArea:setLocation(0, 225, 0);
	elseif rank == 2 then
		self.titleIcon:setAltas("role_title_1", "304000002");
		self.titleIcon:setLocation(0, 380, 0);
		self.rankIcon:setAltas("championship_1", "xui_jys_label_18");
		self.clickArea:SetDimensions(200, 330);
		self.clickArea:setLocation(0, 200, 0);
	else
		self.titleIcon:setAltas("role_title_1", "304000003");
		self.titleIcon:setLocation(0, 380, 0);
		self.rankIcon:setAltas("championship_1", "xui_jys_label_19");
		self.clickArea:SetDimensions(200, 330);
		self.clickArea:setLocation(0, 200, 0);
	end

	self:updateData()
end

function Lua_ChampionshipModelItem:updateData()
	if self.data == nil then
		self.nameText:setLangValue(540016);
		self.btnLike:setEnable(false);
		self.likeCount:setEnable(false);
		self:showRedPoint(false);
	else
		self.nameText.text = self.data.show_role.name;
		self.btnLike:setEnable(true);
		self.likeCount:setEnable(true);
		self.likeCount.text = self.data.like_num;
		if DataCenter.roleData:isMyself(self.data.show_role.id) then
			self:showRedPoint(false);
		else
			self:showRedPoint(self.data.is_praised == 0 and DataCenter.championshipData.leftPariseTimes > 0);
		end
	end
end

function Lua_ChampionshipModelItem:showRedPoint(value)
	if value then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(68, -78)
			self.redPoint:createRedPointImg();
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end

function Lua_ChampionshipModelItem:onLikeClick(go)
	if self.data == nil then
		return;
	end
	if self.data.is_praised == 1 then
		OperateAlert.showLangValue(540017);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sLike(self.data.show_role.id, 1);
end

function Lua_ChampionshipModelItem:onClick(go)
	if self.data == nil then
		return;
	end
	if self.data.is_robot == 1 then
		OperateAlert.showLangValue(123657);
		return;
	end
	if DataCenter.roleData:isMyself(self.data.show_role.id) then
		OperateAlert.showLangValue(123656);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sOtherRoleId(self.data.show_role.id, self.data.show_role.server_flag);
end