-- 竞猜等级奖励
Lua_ChampionshipQuizLevelWindow = class("Lua_ChampionshipQuizLevelWindow", Lua_Window)
function Lua_ChampionshipQuizLevelWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChampionshipQuizLevelWindow";
	self.skinName = "ChampionshipQuizLevelWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ChampionshipQuizLevelWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("CHAMPIONSHIP_QUIZ_LEVEL", self, self.updateShowInfo);

	self.itemList = Lua_DragList.new(self.content, 595, 575, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -35, 0);
	self.itemList:setListCell(Lua_ChampionshipQuizLevelItem, 595, 172, 1);
	self.itemList:setCellSpacing(0, 5);

	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sQuizLevelInfo();
	self:updateShowInfo();
end

function Lua_ChampionshipQuizLevelWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_ChampionshipQuizLevelWindow:updateShowInfo()
	local config = getConfig("classic_event_guess_level_reward");
	local list = {};
	local index = 0;
	for _, v in pairs(config) do
		index = index + 1;
		table.insert(list, index, v);
	end
	table.sort( list, 
		function(a, b) 
			local state_a = DataCenter.championshipData:getQuizLevelState(a.guess_level);
			local state_b = DataCenter.championshipData:getQuizLevelState(b.guess_level);
			if state_a == 0 and state_b == 1 then
				return false;
			elseif state_a == 0 and state_b == 2 then
				return true;
			elseif state_a == 1 and state_b ~= 1 then
				return true;
			elseif state_a == 2 and state_b ~= 2 then
				return false;
			end
			return a.guess_level < b.guess_level;
		end 
			)
	self.itemList:setArrayData(list);
end




















Lua_ChampionshipQuizLevelItem = class("Lua_ChampionshipQuizLevelItem", Lua_ListCell)
function Lua_ChampionshipQuizLevelItem:ctor(p)
	self:superCall("ctor", p, "ChampionshipQuizLevelItem_skin");
end

function Lua_ChampionshipQuizLevelItem:buildShowItem()
	self:superCall("buildShowItem");
	self.btnReceive:addClickFuntion(self, self.onBtnReceiveClick);

	self.itemList = Lua_ItemIconList.new(self.content);
	self.itemList:setLocation(37, -18, 0);
	self.itemList.scaleVal = 0.75;
end

function Lua_ChampionshipQuizLevelItem:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.redPoint then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChampionshipQuizLevelItem:setData(data)
	self.data = data;

	self.levelIcon:setAltas("championship_1", data.icon_sprite);
	self.lvText.text = LanUtil.formateStr(10054, tostring(data.guess_level));
	self.titleText.text = LanUtil.formateStr(540065, tostring(data.guess_level));
	self.levelText.text = LanUtil.formateStr(540066, tostring(data.guess_level));
	self.itemList:setArrayData(data.reward_item);

	local state = DataCenter.championshipData:getQuizLevelState(data.guess_level);
	if state == 0 then
		self.resultIcon:setEnable(true);
		self.resultIcon:setAltas("common_altas_4", "xui_common_label_21");
		self.btnReceive:setEnable(false);
	elseif state == 1 then
		self.resultIcon:setEnable(false);
		self.btnReceive:setEnable(true);
	elseif state == 2 then
		self.resultIcon:setEnable(true);
		self.resultIcon:setAltas("common_altas_1", "xui_common_label_12");
		self.btnReceive:setEnable(false);
	end
	self:showRedPoint(state == 1);
end

function Lua_ChampionshipQuizLevelItem:showRedPoint(value)
	if value then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(260, -3)
			self.redPoint:createRedPointImg();
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end

function Lua_ChampionshipQuizLevelItem:onPressClick()
	self.itemList:onBoundClick();
end

function Lua_ChampionshipQuizLevelItem:onBtnReceiveClick(go)
	if self.data == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sQuizLevelReward(self.data.guess_level);
end