-- 竞猜任务
Lua_ChampionshipQuizTaskWindow = class("Lua_ChampionshipQuizTaskWindow", Lua_Window)
function Lua_ChampionshipQuizTaskWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChampionshipQuizTaskWindow";
	self.skinName = "ChampionshipQuizTaskWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ChampionshipQuizTaskWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("CHAMPIONSHIP_QUIZ_TASK", self, self.updateShowInfo);

	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.checkDetailsIcon:addClickFuntion(self, self.onCheckDetails);
	self.checkDetails:addClickFuntion(self, self.onCheckDetails);

	local roleData = DataCenter.roleData;
	local avatarId = roleData:getOwnDressUpId(Lua_DressUpDefine.MAINTYPE_HEAD);
	local frameId = roleData:getOwnDressUpId(Lua_DressUpDefine.MAINTYPE_FRAME);
	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.86, 0.86, 1);
	self.avatarItem:setLocation(-248, 245.5, 0);
	self.avatarItem:setRoleAvatar(avatarId);
	self.avatarItem:setRoleFrame(frameId);
	self.avatarItem:setRoleVip(roleData.vip);

	self.titleRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Championship_Quiz_Title_Reward)
	self.titleRedPoint:setLocation(280, 270)

	self.itemList = Lua_DragList.new(self.content, 630, 602, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -144, 0);
	self.itemList:setListCell(Lua_ChampionshipQuizTaskItem, 630, 172, 1);
	self.itemList:setCellSpacing(0, 5);

	self:updateShowInfo();
	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sQuizTaskInfo();
end

function Lua_ChampionshipQuizTaskWindow:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.titleRedPoint then
		self.titleRedPoint:dispose();
		self.titleRedPoint = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	self:superCall("dispose");
end

function Lua_ChampionshipQuizTaskWindow:updateShowInfo()
	local data = DataCenter.championshipData;
	self.levelText.text = LanUtil.formateStr(540064, tostring(data.guessLevel));

	local config = getConfig("classic_event_guess_level_reward", data.guessLevel);
	if config.exp_cond and config.exp_cond > 0 then
		local guessExp = DataCenter.moneyData:getMoney(201000031);
		self.levelBar:setMaxValue(config.exp_cond);
		self.levelBar:setValue(guessExp);
		self.levelBar:setText(LanUtil.formateStr(10044, tostring(guessExp), tostring(config.exp_cond)));
	else
		self.levelBar:setMaxValue(1);
		self.levelBar:setValue(1);
		self.levelBar:setLangValue(10045);
	end

	local arr = DataCenter.championshipUtil:getTaskArr();
	self.itemList:setArrayData(arr);
end

function Lua_ChampionshipQuizTaskWindow:onCheckHelp(go)
	local tipsData = { des = LanUtil.getValue(540067), needAdapt = false, posX = -20, posY = 210 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_ChampionshipQuizTaskWindow:onCheckDetails(go)
	Lua_WindowUtil.openWin("Lua_ChampionshipQuizLevelWindow", Lua_WinParam.ACTION_OPEN);
end




















Lua_ChampionshipQuizTaskItem = class("Lua_ChampionshipQuizTaskItem", Lua_ListCell)
function Lua_ChampionshipQuizTaskItem:ctor(p)
	self:superCall("ctor", p, "ChampionshipQuizTaskItem_skin");
end

function Lua_ChampionshipQuizTaskItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_ItemIconList.new(self.content);
	self.itemList:setLocation(-236, -17, 0);
	self.itemList.pivot = 1;
	self.itemList.scaleVal = 0.75;

	self.btnReceive:addClickFuntion(self, self.onBtnReceiveClick);
end

function Lua_ChampionshipQuizTaskItem:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.redPoint then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChampionshipQuizTaskItem:setData(data)
	self.data = data;

	local vo = DataCenter.championshipUtil:getTaskVo(data);
	self.titleText.text = vo.desc;

	if vo.rState == 2 then
		self.rateBar:setEnable(false);
		self.rateText:setEnable(false);
		self.btnReceive:setEnable(false);
		self.stateIcon:setEnable(true);
	elseif vo.rState == 1 then
		self.rateBar:setEnable(false);
		self.rateText:setEnable(false);
		self.btnReceive:setEnable(true);
		self.stateIcon:setEnable(false);
	else
		self.rateBar:setEnable(true);
		self.rateBar:setMaxValue(vo.num);
		self.rateBar:setValue(vo.schedule);
		self.rateText:setEnable(true);
		self.rateText.text = LanUtil.formateStr(10044, tostring(vo.schedule), tostring(vo.num));
		self.btnReceive:setEnable(false);
		self.stateIcon:setEnable(false);	
	end

	self.itemList:setArrayData(vo.task_reward);
	self:showRedPoint(vo.rState == 1);
end

function Lua_ChampionshipQuizTaskItem:showRedPoint(value)
	if value then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content)
			self.redPoint:setLocation(260, -3)
			self.redPoint:createRedPointImg();
		end
		self.redPoint:updateRedPointShow(true)
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false)
		end
	end
end

function Lua_ChampionshipQuizTaskItem:onPressClick()
	self.itemList:onBoundClick();
end

function Lua_ChampionshipQuizTaskItem:onBtnReceiveClick(go)
	if self.data == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ChampionshipProxy"):sQuizTaskReward(self.data);
end